Module Documentation
====================

All functionality of the package is implemented in the ``pydsge.DSGE`` class. An instance of this class holds all information about the model, and the respective methods.

.. autoclass:: pydsge.DSGE
   :members:
   :inherited-members:
